@@ -1,11 +1,11 @@
-from birdbrain.birdbrain_tasks import BirdbrainTasks
+from birdbrain.tasks import Tasks
 
 
 async def method_1(p):
     for i in range(40):
         print("method_1 running", p, i)
 
-        await BirdbrainTasks.yield_task()
+        await Tasks.yield_task()
 
     return "method_1_return"
 
@@ -14,7 +14,7 @@ async def method_2(p):
     for i in range(20):
         print("method_2 running", p, i)
 
-        await BirdbrainTasks.yield_task()
+        await Tasks.yield_task()
 
     return 2
 
@@ -23,11 +23,11 @@ async def method_3():
     for i in range(30):
         print("method_3 running", i)
 
-        await BirdbrainTasks.yield_task()
+        await Tasks.yield_task()
 
 
 def test_tasks_with_wait():
-    tasks = BirdbrainTasks()
+    tasks = Tasks()
 
     tasks.create_task(method_1(999))
     tasks.create_task(method_2("text"))
